16.39. cdist-type__debconf_set_selections(7) — cdist 6.9.8 documentation

# 16.39. cdist-type__debconf_set_selections(7)

## 16.39.1. NAME

cdist-type__debconf_set_selections - Setup debconf selections

## 16.39.2. DESCRIPTION

On Debian and alike systems debconf-set-selections(1) can be used to setup configuration parameters.

## 16.39.3. REQUIRED PARAMETERS

cf. `--line`.

## 16.39.4. OPTIONAL PARAMETERS

file

  Use the given filename as input for debconf-set-selections(1) If filename is `-`, read from stdin.

  This parameter is deprecated, because it doesn't work with state detection.

line

  A line in debconf-set-selections(1) compatible format. This parameter can be used multiple times to set multiple options.

  (This parameter is actually required, but marked optional because the deprecated `--file` is still accepted.)

## 16.39.5. BOOLEAN PARAMETERS

None.

## 16.39.6. EXAMPLES

    # Setup gitolite's gituser
    __debconf_set_selections nslcd --line 'gitolite gitolite/gituser string git'

    # Setup configuration for nslcd from a file.
    # NB: Multiple lines can be passed to --line, although this can be considered a hack.
    __debconf_set_selections nslcd --line "$(cat "${__files:?}/preseed/nslcd.debconf")"

## 16.39.7. SEE ALSO

- cdist-type__update_alternatives(7)

- debconf-set-selections(1)

## 16.39.8. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>
Dennis Camera <dennis.camera--@--ssrq-sds-fds.ch>

## 16.39.9. COPYING

Copyright (C) 2011-2014 Nico Schottelius, 2021 Dennis Camera. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.